/* This file is part of tagr.
   Copyright (C) 2000, 2005,  Max Bouglacoff, Sergey Poznyakoff

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA. */

#include <time.h>
#include <errno.h>

#define LOGFACILITY LOG_LOCAL5
#define TAGR_CONFIGFILE SYSCONFDIR "/tagr.conf"
#define TAGR_TEMPLATE SYSCONFDIR "/tagr.tmpl"
#define TAGR_PIDFILE "/var/run/tagr.pid"

typedef struct HostData {
	char	id[16];
	char	name[32];
	char	dir[1024];
	time_t	t;
	int	in;
	int	out;
	int	max;
} SD;


extern char	rateup[];
extern char     *user;
extern char	*basedir;
extern char	*configfile;
extern SD	*sd;
extern size_t   sd_count;
extern int	port;
extern char *progname;
extern int foreground;
extern char *html_template;
extern char *html_input_file;
extern int html_input_line;

int readconfig ( void );
int call_rateup ( SD* );
int frateup ( char*, char*, char*, char*, int, int, int, int );
void decode_buffer();

void begin_eval();
void end_eval();
int html_open(char *file);
void html_close();
int yyerror(char *s);

typedef enum { unspecified_value, numeric_value, string_value } value_type;

typedef struct {
	value_type type;
	int prec;
	union {
		double number;
		char *string;
	} v;
} pp_value_t;

typedef struct pp_value_list {
	struct pp_value_list *next;
	char *name;
	pp_value_t value;
} pp_tab_t;

void add_numeric_value (pp_tab_t **ptab, char *name, double number);
void add_string_value (pp_tab_t **ptab, char *name, char *string);
int find_value (char *name, pp_value_t *val);
void free_tab(pp_tab_t **ptab);
int create_html(pp_tab_t *tab, char *file, char *dest);
int check_template();

/* Logging */
#define L_DEBUG   0
#define L_INFO    1 
#define L_NOTICE  2
#define L_WARNING 3
#define L_ERR     4
#define L_CRIT    5


extern int use_stderr;

void init_syslog(char *name);
void logmsg(int level, const char *fmt, ...);
void die(int code, const char *fmt, ...);

